@@ -20,7 +20,7 @@ Usage:
     chromosight quantify [--inter] [--pattern=loops] [--subsample=no]
                          [--win-fmt=json] [--kernel-config=FILE] [--force-norm]
                          [--threads=1] [--full] [--n-mads=5] [--win-size=auto]
-                         [--tsvd] <bed2d> <contact_map> <output>
+                         [--no-plotting] [--tsvd] <bed2d> <contact_map> <output>
     chromosight test
 
     detect:
@@ -218,6 +218,7 @@ def cmd_quantify(args):
     pattern = args["--pattern"]
     inter = args["--inter"]
     kernel_config_path = args["--kernel-config"]
+    plotting_enabled = False if args["--no-plotting"] else True
     threads = int(args["--threads"])
     force_norm = args["--force-norm"]
     tsvd = 0.999 if args["--tsvd"] else None
@@ -261,6 +262,8 @@ def cmd_quantify(args):
     max_diag = hic_genome.clr.shape[0] * hic_genome.clr.binsize
     cfg["max_dist"] = min(furthest, max_diag)
     cfg["min_dist"] = 0
+    cfg["max_perc_undetected"] = 100
+
     # Notify contact map instance of changes in scanning distance
     hic_genome.kernel_config = cfg
     # Normalize (balance) matrix using ICE
@@ -274,10 +277,12 @@ def cmd_quantify(args):
     bed2d["score"] = np.nan
     bed2d["pvalue"] = np.nan
     positions = bed2d.copy()
+    # Only resize kernel matrix if explicitely requested
+    km, kn = cfg["kernels"][0].shape
     if win_size != "auto":
+        for i, k in enumerate(cfg['kernels']):
+            cfg['kernels'][i] = resize_kernel(k, factor=win_size / km)
         km = kn = win_size
-    else:
-        km, kn = cfg["kernels"][0].shape
     windows = np.full((positions.shape[0], km, kn), np.nan)
     # For each position, we use the center of the BED interval
     positions["pos1"] = (positions.start1 + positions.end1) // 2
@@ -285,9 +290,6 @@ def cmd_quantify(args):
     # Use each kernel matrix available for the pattern
     for kernel_id, kernel_matrix in enumerate(cfg["kernels"]):
         cio.progress(kernel_id, len(cfg["kernels"]), f"Kernel: {kernel_id}\n")
-        # Only resize kernel matrix if explicitely requested
-        if win_size != "auto":
-            kernel_matrix = resize_kernel(kernel_matrix, factor=win_size / km)
         # Iterate over intra- and inter-chromosomal sub-matrices
         n_sub_mats = hic_genome.sub_mats.shape[0]
         for sub_mat_id, sub_mat in enumerate(hic_genome.sub_mats.iterrows()):
@@ -343,7 +345,7 @@ def cmd_quantify(args):
                     # if better than results from previous kernels
                     better = (
                         patterns.score > bed2d["score"][sub_pat_idx].values
-                    )
+                    ) | (np.insnan(bed2d["score"][sub_pat_idx].values))
                     better_idx = sub_pat_idx[better]
                     bed2d["score"][better_idx] = patterns.score[better]
                     windows[better_idx, :, :] = mat_windows[better]
@@ -389,6 +391,14 @@ def cmd_quantify(args):
         cio.save_windows(
             windows, f"{pattern}_quant", output_dir=output, format=win_fmt
         )
+        # Generate pileup visualisations if requested
+        if plotting_enabled:
+            # Compute and plot pileup
+            pileup_fname = ("pileup_of_{n}_{pattern}").format(
+                pattern=cfg["name"], n=windows.shape[0]
+            )
+            windows_pileup = cid.pileup_patterns(windows)
+            pileup_plot(windows_pileup, name=pileup_fname, output=output)
 
 
 def cmd_generate_config(args):
@@ -574,8 +584,8 @@ def cmd_detect(args):
     # matrix is processed on the fly (obs / exp, trimming diagonals > max dist)
     hic_genome.make_sub_matrices()
 
-    all_pattern_coords = []
-    all_pattern_windows = []
+    all_coords = []
+    all_windows = []
 
     ### 2: DETECTION ON EACH SUBMATRIX
     pool = mp.Pool(threads)
@@ -637,13 +647,13 @@ def cmd_detect(args):
                     ],
                     axis=0,
                 )
-                all_pattern_coords.append(
+                all_coords.append(
                     pd.concat(kernel_coords, axis=0).reset_index(drop=True)
                 )
                 # Add info about kernel and iteration which detected these patterns
-                all_pattern_coords[-1]["kernel_id"] = kernel_id
-                all_pattern_coords[-1]["iteration"] = i
-                all_pattern_windows.append(kernel_windows)
+                all_coords[-1]["kernel_id"] = kernel_id
+                all_coords[-1]["iteration"] = i
+                all_windows.append(kernel_windows)
 
             # If no pattern was found with this kernel
             # skip directly to the next one, skipping iterations
@@ -655,16 +665,14 @@ def cmd_detect(args):
             run_id += 1
     cio.progress(run_id, total_runs, f"Kernel: {kernel_id}, Iteration: {i}\n")
     # If no pattern detected on any chromosome, with any kernel, exit gracefully
-    if len(all_pattern_coords) == 0:
+    if len(all_coords) == 0:
         sys.stderr.write("No pattern detected ! Exiting.\n")
         sys.exit(0)
 
     # Combine patterns of all kernel matrices into a single array
-    all_pattern_coords = pd.concat(all_pattern_coords, axis=0).reset_index(
-        drop=True
-    )
+    all_coords = pd.concat(all_coords, axis=0).reset_index(drop=True)
     # Combine all windows from different kernels into a single pile of windows
-    all_pattern_windows = np.concatenate(all_pattern_windows, axis=0)
+    all_windows = np.concatenate(all_windows, axis=0)
 
     # Compute minimum separation in bins and make sure it has a reasonable value
     separation_bins = int(cfg["min_separation"] // hic_genome.clr.binsize)
@@ -673,40 +681,38 @@ def cmd_detect(args):
     print(f"Minimum pattern separation is : {separation_bins}")
     # Remove patterns with overlapping windows (smeared patterns)
     distinct_patterns = cid.remove_neighbours(
-        all_pattern_coords, win_size=separation_bins
+        all_coords, win_size=separation_bins
     )
 
     # Drop patterns that are too close to each other
-    all_pattern_coords = all_pattern_coords.loc[distinct_patterns, :]
-    all_pattern_windows = all_pattern_windows[distinct_patterns, :, :]
+    all_coords = all_coords.loc[distinct_patterns, :]
+    all_windows = all_windows[distinct_patterns, :, :]
 
     # Get from bins into basepair coordinates
-    coords_1 = hic_genome.bins_to_coords(all_pattern_coords.bin1).reset_index(
+    coords_1 = hic_genome.bins_to_coords(all_coords.bin1).reset_index(
         drop=True
     )
     coords_1.columns = [str(col) + "1" for col in coords_1.columns]
-    coords_2 = hic_genome.bins_to_coords(all_pattern_coords.bin2).reset_index(
+    coords_2 = hic_genome.bins_to_coords(all_coords.bin2).reset_index(
         drop=True
     )
     coords_2.columns = [str(col) + "2" for col in coords_2.columns]
 
-    all_pattern_coords = pd.concat(
-        [all_pattern_coords.reset_index(drop=True), coords_1, coords_2], axis=1
+    all_coords = pd.concat(
+        [all_coords.reset_index(drop=True), coords_1, coords_2], axis=1
     )
 
     # Filter patterns closer than minimum distance from the diagonal if any
-    min_dist_drop_mask = (
-        all_pattern_coords.chrom1 == all_pattern_coords.chrom2
-    ) & (
-        np.abs(all_pattern_coords.start2 - all_pattern_coords.start1)
-        < cfg["min_dist"]
+    min_dist_drop_mask = (all_coords.chrom1 == all_coords.chrom2) & (
+        np.abs(all_coords.start2 - all_coords.start1) < cfg["min_dist"]
     )
-    all_pattern_coords = all_pattern_coords.loc[~min_dist_drop_mask, :]
-    all_pattern_windows = all_pattern_windows[~min_dist_drop_mask, :, :]
+    all_coords = all_coords.loc[~min_dist_drop_mask, :]
+    all_windows = all_windows[~min_dist_drop_mask, :, :]
+
     # Correct p-values for multiple testing using FDR
-    all_pattern_coords["qvalue"] = fdr_correction(all_pattern_coords["pvalue"])
+    all_coords["qvalue"] = fdr_correction(all_coords["pvalue"])
     # Reorder columns
-    all_pattern_coords = all_pattern_coords.loc[
+    all_coords = all_coords.loc[
         :,
         [
             "chrom1",
@@ -726,21 +732,19 @@ def cmd_detect(args):
     ]
 
     ### 3: WRITE OUTPUT
-    sys.stderr.write(f"{all_pattern_coords.shape[0]} patterns detected\n")
+    sys.stderr.write(f"{all_coords.shape[0]} patterns detected\n")
     # Save patterns and their coordinates in a tsv file
-    cio.write_patterns(all_pattern_coords, cfg["name"] + "_out", output)
+    cio.write_patterns(all_coords, cfg["name"] + "_out", output)
     # Save windows as an array in an npy file
-    cio.save_windows(
-        all_pattern_windows, cfg["name"] + "_out", output, format=win_fmt
-    )
+    cio.save_windows(all_windows, cfg["name"] + "_out", output, format=win_fmt)
 
     # Generate pileup visualisations if requested
     if plotting_enabled:
         # Compute and plot pileup
         pileup_fname = ("pileup_of_{n}_{pattern}").format(
-            pattern=cfg["name"], n=all_pattern_windows.shape[0]
+            pattern=cfg["name"], n=all_windows.shape[0]
         )
-        windows_pileup = cid.pileup_patterns(all_pattern_windows)
+        windows_pileup = cid.pileup_patterns(all_windows)
         pileup_plot(windows_pileup, name=pileup_fname, output=output)
 
 
