@@ -79,7 +79,7 @@ def validate_patterns(
     # Initialize structure to store pattern windows
     pattern_windows = np.full(
         (coords.shape[0], win_h, win_w), np.nan
-    )  # list containing all pannel of detected patterns
+    )  # list containing all panel of detected patterns
     for i, l in enumerate(coords):
         p1 = int(l[0])
         p2 = int(l[1])
@@ -298,6 +298,11 @@ def pattern_detector(
             shape=mat.shape,
             format="csr",
         )
+        # When detecting 1D pattern, enforce coordinates on diagonal
+        # coordinates can be shifted by 1 since we keep the two first
+        # diagonals to allow formation of foci via 4-way adjacency
+        if kernel_config["max_dist"] == 0:
+            coords[:, 0] = coords[:, 1]
 
     # Extract windows around coordinates and assign a correlation
     # to each pattern. In detection mode, we drop invalid patterns
